init_tracing

Function init_tracing 

pub fn init_tracing()
Installs a tracing subscriber for Basilisk diagnostics.

The subscriber uses the RUST_LOG environment variable when it is set and defaults to the INFO level otherwise. Calling this is safe when the host application has already installed a subscriber; its initialization attempt is ignored in that case.